@@ -863,6 +863,9 @@ class BigQuery(Dialect):
             "TRANSLATE": lambda self: self._parse_translate(),
             "FEATURES_AT_TIME": lambda self: self._parse_features_at_time(),
             "GENERATE_EMBEDDING": lambda self: self._parse_ml(exp.GenerateEmbedding),
+            "GENERATE_TEXT_EMBEDDING": lambda self: self._parse_ml(
+                exp.GenerateEmbedding, is_text=True
+            ),
             "VECTOR_SEARCH": lambda self: self._parse_vector_search(),
             "FORECAST": lambda self: self._parse_ml(exp.MLForecast),
         }
@@ -894,8 +897,6 @@ class BigQuery(Dialect):
         RANGE_PARSERS = parser.Parser.RANGE_PARSERS.copy()
         RANGE_PARSERS.pop(TokenType.OVERLAPS)
 
-        NULL_TOKENS = {TokenType.NULL, TokenType.UNKNOWN}
-
         DASHED_TABLE_PART_FOLLOW_TOKENS = {TokenType.DOT, TokenType.L_PAREN, TokenType.R_PAREN}
 
         STATEMENT_PARSERS = {
@@ -1148,7 +1149,7 @@ class BigQuery(Dialect):
 
             return expr
 
-        def _parse_ml(self, expr_type: t.Type[E]) -> E:
+        def _parse_ml(self, expr_type: t.Type[E], **kwargs) -> E:
             self._match_text_seq("MODEL")
             this = self._parse_table()
 
@@ -1167,6 +1168,7 @@ class BigQuery(Dialect):
                 this=this,
                 expression=expression,
                 params_struct=self._parse_bitwise(),
+                **kwargs,
             )
 
         def _parse_translate(self) -> exp.Translate | exp.MLTranslate:
