@@ -1631,6 +1631,30 @@ BINARY;
 COMPRESS('Hello World', 'zlib(1)');
 BINARY;
 
+# dialect: snowflake
+DECOMPRESS_BINARY('compressed_data', 'SNAPPY');
+BINARY;
+
+# dialect: snowflake
+DECOMPRESS_STRING('compressed_data', 'ZSTD');
+VARCHAR;
+
+# dialect: snowflake
+LPAD('Hello', 10, '*');
+VARCHAR;
+
+# dialect: snowflake
+LPAD(tbl.str_col, 10);
+VARCHAR;
+
+# dialect: snowflake
+LPAD(tbl.bin_col, 10, 0x20);
+BINARY;
+
+# dialect: snowflake
+COLLATION('hello');
+VARCHAR;
+
 # dialect: snowflake
 CONCAT('Hello', 'World!');
 VARCHAR;
@@ -1727,6 +1751,18 @@ VARCHAR;
 INITCAP(tbl.str_col);
 VARCHAR;
 
+# dialect: snowflake
+JAROWINKLER_SIMILARITY('hello', 'world');
+INT;
+
+# dialect: snowflake
+INSERT('abc', 1, 2, 'Z');
+VARCHAR;
+
+# dialect: snowflake
+INSERT(tbl.bin_col, 1, 2, tbl.bin_col);
+BINARY;
+
 # dialect: snowflake
 LEAST(x::DECIMAL(18, 2));
 DECIMAL(18, 2);
